
---------------------------------------------------
-- JS VGA TEST
---------------------------------------------------
-- V 1.0 06/2006 initial version
-- V 1.1 09/2006 version 800 x 600 unsynched
-- V 2.1 03/2007 adaption for S3E, synched version
-- V 2.2 11/2007 colour shift / multiplex / reset
-- V 3.0 04/2008 mesh, colour moving
-- V 3.1 05/2008 design changed , chipscope file
-- V 3.2 07/2009 cursor / ball added, synch changed
-- V 4.0 02/2012 ported to spartan 6
-- V 4.1 04/2012 ported to spartan 6 - TE630carrier
-- V 4.2 04/2016 changed to avoid pll problem
---------------------------------------------------

---------------------------------------------------
-- This Design is optimized for Trenz TE0304carrier
-- with a TE630 Spartan LX 75 module mounted
-- 100 MHz OSC
---------------------------------------------------

library ieee;
  use ieee.std_logic_1164.all;
  use ieee.std_logic_unsigned.all;
  use ieee.numeric_std.all;

-- library UNISIM;
-- use UNISIM.Vcomponents.all;


entity jsvgacore_s6 is
port
(
		MOD_VAR		: in    std_logic_vector (3 downto 0);
		RESET       : in    std_logic;	-- active high from push buttom
		CLK_OSC_100 : in    std_logic;	-- osc 100 MHz fixed type
		--
		VIDEO_R		: out   std_logic_vector (4 downto 0);
		VIDEO_G    	: out   std_logic_vector (4 downto 0);
		VIDEO_B    	: out   std_logic_vector (4 downto 0);
		N_HSYNC     : out   std_logic;
		N_VSYNC     : out   std_logic;
		VGA_SCL		: out   std_logic;
		VGA_SDA		: out   std_logic;
		--
		GPIO_D_OUT	: out   std_logic_vector (3 downto 0)
	);
end jsvgacore_s6;





architecture a of jsvgacore_s6 is

	signal clk_pixel		: std_logic;
	
	signal ext_reset		: std_logic;
   signal ext_reset_d1	: std_logic;
   signal ext_reset_d2	: std_logic;
	
	signal sig_h_synch	: std_logic;
   signal sig_v_synch	: std_logic;
   
	signal clk_sys_cnt	: std_logic_vector(27 downto 0);
 
   signal sig_video_r   : std_logic_vector (4 downto 0);
   signal sig_video_g   : std_logic_vector (4 downto 0);
   signal sig_video_b   : std_logic_vector (4 downto 0);
 

begin


VGA_SCL <= 'Z';
VGA_SDA <= 'Z';


clkgen : entity work.clkgen
port map (
   CLK_IN1	  			=> CLK_OSC_100,
   RESET  				=> RESET,
   CLK_OUT1 			=> clk_pixel,  -- 50 MHz
	LOCKED				=> open
);

	 

mk_reset : process(clk_pixel)
begin
	if rising_edge(clk_pixel) then
	
		if (RESET = '1') then
			ext_reset      <= '1';
		else
			ext_reset <= '0';
		end if;
      
      ext_reset_d1	<= ext_reset;
      ext_reset_d2	<= ext_reset_d1;
		
		clk_sys_cnt	<= std_logic_vector(unsigned(clk_sys_cnt) +1);
					
	end if;
			
end process;



vgaout : entity work.VIDEO_OUT
	port map (
	  RESET				=> ext_reset_d2,
	  PIXEL_CLOCK   	=> clk_pixel,
	  VIDEO_R       	=> sig_video_r,
	  VIDEO_G       	=> sig_video_g,
	  VIDEO_B       	=> sig_video_b,
	  HSYNC         	=> sig_h_synch,
	  VSYNC         	=> sig_v_synch
);



mk_outs : process(clk_pixel)
begin
	if rising_edge(clk_pixel) then
   
      N_HSYNC  <= not sig_h_synch;
      N_VSYNC	<= not sig_v_synch;
	  
      VIDEO_R  <= sig_video_r;
      VIDEO_G  <= sig_video_g;
      VIDEO_B  <= sig_video_b;
     
      GPIO_D_OUT <= clk_sys_cnt(27 downto 24);
	  
   end if;
			
end process;


end a;
